@@ -618,7 +618,7 @@ def lastupdate(args):
     """Identify when an update was last performed"""
     command = ("ls -l --full-time " + util.available_file + " 2> "
                "/dev/null | awk '{printf \"Last update was %s %s %s\\n\""
-               ", $6, $7, $8}' | sed 's|\.000000000||'")
+               r", $6, $7, $8}' | sed 's|\.000000000||'")
     perform.execute(command, teach=args.teach, noop=args.noop)
 
 
@@ -650,7 +650,7 @@ def listcache(args):
 def listalternatives(args):
     """List the objects that can have alternatives configured"""
     command = ("ls /etc/alternatives/ | "
-               "grep -E -v '(\.1|\.1\.gz|\.8|\.8\.gz|README)$'")
+               r"grep -E -v '(\.1|\.1\.gz|\.8|\.8\.gz|README)$'")
     perform.execute(command, teach=args.teach, noop=args.noop)
 
 
@@ -1046,8 +1046,8 @@ def reportbug(args):
     
 def repos(args):
     """List the added personal package archives (PPAs)"""
-    command  = 'for SRC in `find /etc/apt/ -name \*.list`; do '
-    command += 'grep -o "^deb https://ppa.launchpad.net/[a-z0-9\-]\+/[a-z0-9\-]\+" $SRC; done | '
+    command  = r'for SRC in `find /etc/apt/ -name \*.list`; do '
+    command += r'grep -o "^deb https://ppa.launchpad.net/[a-z0-9\-]\+/[a-z0-9\-]\+" $SRC; done | '
     command += "perl -p -e 's|^.*(ppa)[^/]*/|ppa:|'"
     perform.execute(command, teach=args.teach, noop=args.noop)
     
@@ -1097,6 +1097,12 @@ def rpminstall(args):
     command = "/usr/bin/alien --install " + args.rpm
     perform.execute(command, root=True, log=True, teach=args.teach, noop=args.noop)
 
+def safeupgrade(args):
+    """Safely upgrade pacakges that are currently deferred due to phasing of their release."""
+    command = "/usr/bin/aptitude safe-upgrade {}"
+    # 20241205 gjw `aptitude` only supports `-y`, not `--yes`
+    command = command.format('-y' if args.yes == ' --yes ' else '')
+    perform.execute(command, root=True, log=True, teach=args.teach, noop=args.noop)
 
 def search(args):
     """Search for package names containing the given pattern
@@ -1121,7 +1127,7 @@ def search(args):
         args.patterns = [shlex.quote(pattern) for pattern in args.patterns]
         command = "apt-cache search {} | grep -E --ignore-case '{}'"
         command = command.format(" ".join(args.patterns),
-                                 "\|".join(args.patterns))
+                                 r"\|".join(args.patterns))
     else:
         command = "apt-cache search --full " + " ".join(args.patterns)
     perform.execute(command, teach=args.teach, noop=args.noop)
@@ -1185,7 +1191,7 @@ def source(args):
 def status(args):
     """Show the version and available versions of packages (with regexp support)"""
     pkgs = []
-    regexp = set('.^$*+?{},\[]|()')
+    regexp = set(r'.^$*+?{},\[]|()')
     for p in args.pattern:
         notregexp = not any((c in regexp for c in p))
         if notregexp:
@@ -1253,7 +1259,7 @@ def sysinfo(args):
         command  =  'GPU=$(lspci | grep VGA | cut -d ":" -f3); '
         command += 'RAM=$(cardid=$(lspci | grep VGA |cut -d " " -f1); '
         command += 'lspci -v -s $cardid | grep " prefetchable"| '
-        command += 'cut -d "=" -f2 | tr -d "\]"); '
+        command += r'cut -d "=" -f2 | tr -d "\]"); '
         command += 'echo $GPU $RAM'
         result  = perform.execute(command, getoutput=True, teach=args.teach,
                                   noop=args.noop).decode("utf-8").strip()
@@ -1409,23 +1415,43 @@ def updateusbids(args):
 def upgrade(args):
     """Conservative system upgrade
 
-    This will not go as far remove packages in order to fulfill the
+    This will not go as far as removing packages in order to fulfill the
     upgrade, so may leave stale packages around. Use 'dist-upgrade' to
     avoid that.
     """
+
+    # print("COMMANDS TEACH = " + str(args.teach))
+    # print("COMMANDS LOCAL = " + str(args.local))
+    # print("COMMANDS NOAUTH = " + str(args.noauth))
+    # print("COMMANDS YES = " + str(args.yes))
+
+    # 20241205 gjw Migrate from `apt-get` to the new `apt` where
+    # `--yes` is working, unlike `apt-get` which has come to ignore
+    # `--yes` sometime in the past and always ask. As per
+    # https://github.com/gjwgit/wajig/issues/22 we set `--yes` by
+    # default for upgrade as that is the behaviour users have come to
+    # expect in `wajig` though contrary the original intent some 20
+    # years ago!
+
     packages = util.upgradable()
-    if packages:
-        if args.backup:
-            util.requires_package("dpkg-repack")
-            util.requires_package("fakeroot")
-            util.backup_before_upgrade(packages)
-        command = (
-            "/usr/bin/apt-get {} {} {} --show-upgraded --with-new-pkgs upgrade"
-        )
-        command = command.format(args.local, args.yes, args.noauth)
-        perform.execute(command, root=True, log=True, teach=args.teach, noop=args.noop)
-    else:
-        print(NO_UPGRADES)
+
+    # if packages:
+
+    if args.backup:
+        util.requires_package("dpkg-repack")
+        util.requires_package("fakeroot")
+        util.backup_before_upgrade(packages)
+    command = (
+        "/usr/bin/apt {} {} {} --yes --show-upgraded --with-new-pkgs upgrade"
+    )
+    command = command.format(args.local, args.yes, args.noauth)
+    perform.execute(command, root=True, log=True, teach=args.teach, noop=args.noop)
+
+    # else:
+    #   print(NO_UPGRADES)
+
+    if not packages:
+        print('To install any packages being phased try `wajig safeupgrade`.')
 
 
 def upgradesecurity(args):
